#!/usr/bin/php -q
<?php

if (php_sapi_name() !='cli') exit; // die if not running from command line

$engine = isset($argv[1])?$argv[1]:'freepbx';
$cmd    = isset($argv[2])?$argv[2]:'destinations';

if($engine=='issabel') {

    $bootstrap_settings = array();
    $bootstrap_settings['skip_astman']=false;
    $bootstrap_settings['issabelpbx_auth']=false;
    require_once("/etc/issabelpbx.conf");

    $exten_usage=array();
    foreach($active_modules as $rawmod => $module){
        $funct = strtolower($rawmod.'_destinations');
        if (function_exists($funct)) {
            modgettext::push_textdomain($rawmod);
            $destArray = $funct(); //returns an array with 'destination' and 'description', and optionally 'category'
            modgettext::pop_textdomain();
            if(is_Array($destArray)) {
                foreach($destArray as $dest){
                    $cat=(isset($dest['category'])?$dest['category']:dgettext($rawmod,$module['displayname']));
                    $ds_id = (isset($dest['id']) ? $dest['id'] : $rawmod);
                    $drawselect_destinations[$cat][] = $dest;
                }
            }
        }
    }

    $full_list = framework_check_extension_usage(true);
    foreach ($full_list as $module => $entries) {
        foreach ($entries as $exten => $stuff) {
            $extmap[$exten] = $stuff['description'];
        }
    }

    $used_extensions=array();
    foreach ($extmap as $exten=>$desc) {
        $used_extensions[]=$exten.'';
    }

    $mydest = array();
    foreach($drawselect_destinations as $category=>$arr) {
        foreach($arr as $idx=>$data) {
            $mydest[$category][]=array("name"=>$data['description'],"destination"=>$data['destination']);
        }
    }

    if($cmd=='extensions') {
        // returns used extensions
        echo json_encode($used_extensions);
    } else if($cmd=='destinations') {
        // returns available destinations
        echo json_encode($mydest);
    } else if($cmd=='regenerate') {
        // regenerates dialplan
        do_reload();
    }
    die();

} else if($engine=='freepbx') {

    $bootstrap_settings = array();
    $bootstrap_settings['skip_astman']=false;
    $bootstrap_settings['freepbx_auth']=false;
    require_once("/etc/freepbx.conf");

    $o = FreePBX::Destinations()->getAll(null);
    $mydest = array();
    foreach($o as $uno=>$dos) {
        foreach($dos as $key=>$val) {
            if(count($val['destinations'])>0) {
                foreach($val['destinations'] as $idx=>$info) {
                    $cat = isset($info['category'])?$info['category']:$info['name'];
                    $mydest[$cat][]=array("name"=>$info['description'],"destination"=>$info['destination']);
                }
            }
        }
    }
    $p = FreePBX::Extensions()->getExtmap();
    $used_extensions=array();
    foreach($p as $exten=>$mod) {
        $used_extensions[]=$exten.'';
    }

    if($cmd=='extensions') {
        // returns used extensions
        echo json_encode($used_extensions);
    } else if($cmd=='destinations') {
        // returns available destinations
        echo json_encode($mydest);
    } else if($cmd=='regenerate') {
        // regenerates dialplan

        $AMPSBIN = FreePBX::Config()->get('AMPSBIN');
        if(!file_exists($AMPSBIN.'/fwconsole')) {
            $out = fpbx_which('fwconsole');
            if(empty($out)) {
                die("fwconsole not found");
            }
        }
        if(!is_executable($AMPSBIN.'/fwconsole')) {
            die("fwconsole not executable");
        }
        $process = new \Symfony\Component\Process\Process($AMPSBIN.'/fwconsole reload --json');
        $process->setTimeout(1800);
        $process->run();
        $output = $process->getOutput();
        $code = $process->getExitCode();

    }
    die();
 
} else {

    $used_extensions = array('200','201');

    $mydest = array();
    $mydest['Extensions'][]=array("name"=>"John Doe","destination"=>"default,200,1");
    $mydest['Extensions'][]=array("name"=>"Mary Poppins","destination"=>"default,201,1");

    if($cmd=='extensions') {
        // returns used extensions
        echo json_encode($used_extensions);
    } else if($cmd=='destinations') {
        // returns available destinations
        echo json_encode($mydest);
    } else if($cmd=='regenerate') {
        // regenerates dialplan
    }
    die();
 
}

